pub struct CreateFirewallPolicyRequest {Show 22 fields
pub name: String,
pub action: FirewallAction,
pub source_zone_id: EntityId,
pub destination_zone_id: EntityId,
pub enabled: bool,
pub logging_enabled: bool,
pub allow_return_traffic: Option<bool>,
pub description: Option<String>,
pub ip_version: Option<String>,
pub connection_states: Option<Vec<String>>,
pub source_filter: Option<TrafficFilterSpec>,
pub destination_filter: Option<TrafficFilterSpec>,
pub src_network: Option<Vec<String>>,
pub src_ip: Option<Vec<String>>,
pub src_port: Option<Vec<String>>,
pub dst_network: Option<Vec<String>>,
pub dst_ip: Option<Vec<String>>,
pub dst_port: Option<Vec<String>>,
pub src_port_group: Option<String>,
pub dst_port_group: Option<String>,
pub src_address_group: Option<String>,
pub dst_address_group: Option<String>,
}Fields
name: Stringaction: FirewallActionsource_zone_id: EntityIddestination_zone_id: EntityIdenabled: boollogging_enabled: boolallow_return_traffic: Option<bool>description: Option<String>ip_version: Option<String>connection_states: Option<Vec<String>>source_filter: Option<TrafficFilterSpec>destination_filter: Option<TrafficFilterSpec>src_network: Option<Vec<String>>src_ip: Option<Vec<String>>src_port: Option<Vec<String>>dst_network: Option<Vec<String>>dst_ip: Option<Vec<String>>dst_port: Option<Vec<String>>src_port_group: Option<String>dst_port_group: Option<String>src_address_group: Option<String>dst_address_group: Option<String>Implementations
Sourceimpl CreateFirewallPolicyRequest
impl CreateFirewallPolicyRequest
Sourcepub fn resolve_filters(&mut self) -> Result<(), String>
pub fn resolve_filters(&mut self) -> Result<(), String>
Convert shorthand src_ip/dst_ip/src_port/dst_port/src_network/
dst_network fields into the canonical source_filter/destination_filter.
Returns Err if both a shorthand field and the corresponding filter are set,
or if more than one shorthand family is specified for the same side.